package com.playlet.web.controller.system;

import java.util.List;

import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseBody;
import com.playlet.common.annotation.Log;
import com.playlet.common.enums.BusinessType;
import com.playlet.system.domain.PlayletUserAccount;
import com.playlet.system.service.IPlayletUserAccountService;
import com.playlet.common.core.controller.BaseController;
import com.playlet.common.core.domain.AjaxResult;
import com.playlet.common.utils.poi.ExcelUtil;
import com.playlet.common.core.page.TableDataInfo;

/**
 * @Date: 2024-03-25 15:30
 * @Author: 但星霖
 * @Version: v1.0
 * @Description: 短剧用户提现账户Controller
 */
@Controller
@RequestMapping("/system/account")
public class PlayletUserAccountController extends BaseController {
    private String prefix = "system/account";

    @Autowired
    private IPlayletUserAccountService playletUserAccountService;

    @RequiresPermissions("system:account:view")
    @GetMapping()
    public String account() {
        return prefix + "/account";
    }

    /**
     * 查询短剧用户提现账户列表
     */
    @RequiresPermissions("system:account:list")
    @PostMapping("/list")
    @ResponseBody
    public TableDataInfo list(PlayletUserAccount playletUserAccount) {
        startPage();
        List<PlayletUserAccount> list = playletUserAccountService.selectPlayletUserAccountList(playletUserAccount);
        return getDataTable(list);
    }

    /**
     * 导出短剧用户提现账户列表
     */
    @RequiresPermissions("system:account:export")
    @Log(title = "短剧用户提现账户", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    @ResponseBody
    public AjaxResult export(PlayletUserAccount playletUserAccount) {
        List<PlayletUserAccount> list = playletUserAccountService.selectPlayletUserAccountList(playletUserAccount);
        ExcelUtil<PlayletUserAccount> util = new ExcelUtil<PlayletUserAccount>(PlayletUserAccount.class);
        return util.exportExcel(list, "短剧用户提现账户数据");
    }

    /**
     * 新增短剧用户提现账户
     */
    @GetMapping("/add")
    public String add() {
        return prefix + "/add";
    }

    /**
     * 新增保存短剧用户提现账户
     */
    @RequiresPermissions("system:account:add")
    @Log(title = "短剧用户提现账户", businessType = BusinessType.INSERT)
    @PostMapping("/add")
    @ResponseBody
    public AjaxResult addSave(PlayletUserAccount playletUserAccount) {
        return toAjax(playletUserAccountService.insertPlayletUserAccount(playletUserAccount));
    }

    /**
     * 修改短剧用户提现账户
     */
    @RequiresPermissions("system:account:edit")
    @GetMapping("/edit/{id}")
    public String edit(@PathVariable("id") Long id, ModelMap mmap) {
        PlayletUserAccount playletUserAccount = playletUserAccountService.selectPlayletUserAccountById(id);
        mmap.put("playletUserAccount", playletUserAccount);
        return prefix + "/edit";
    }

    /**
     * 修改保存短剧用户提现账户
     */
    @RequiresPermissions("system:account:edit")
    @Log(title = "短剧用户提现账户", businessType = BusinessType.UPDATE)
    @PostMapping("/edit")
    @ResponseBody
    public AjaxResult editSave(PlayletUserAccount playletUserAccount) {
        return toAjax(playletUserAccountService.updatePlayletUserAccount(playletUserAccount));
    }

    /**
     * 删除短剧用户提现账户
     */
    @RequiresPermissions("system:account:remove")
    @Log(title = "短剧用户提现账户", businessType = BusinessType.DELETE)
    @PostMapping("/remove")
    @ResponseBody
    public AjaxResult remove(String ids) {
        return toAjax(playletUserAccountService.deletePlayletUserAccountByIds(ids));
    }
}
